@@ -7,6 +7,12 @@ setup(
     include_package_data=True,
     install_requires=[
         'Click',
+        'boto3',
+        'keyring',
+        'warrant',
+        's3fs',
+        'zarr',
+        'torch'
     ],
     entry_points='''
         [console_scripts]
